/*
 * Copyright 2017-2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

#include <stdint.h>
#include "fsl_common.h"
#include "fsl_debug_console.h"
#include "board.h"
#if defined(SDK_I2C_BASED_COMPONENT_USED) && SDK_I2C_BASED_COMPONENT_USED
#include "fsl_i2c.h"
#endif /* SDK_I2C_BASED_COMPONENT_USED */

/*******************************************************************************
 * Variables
 ******************************************************************************/

/*******************************************************************************
 * Code
 ******************************************************************************/
/* Initialize debug console. */
void BOARD_InitDebugConsole(void)
{
    /* attach 12 MHz clock to FLEXCOMM0 (debug console) */
    CLOCK_AttachClk(BOARD_DEBUG_UART_CLK_ATTACH);

    RESET_ClearPeripheralReset(BOARD_DEBUG_UART_RST);

    uint32_t uartClkSrcFreq = BOARD_DEBUG_UART_CLK_FREQ;

    DbgConsole_Init(BOARD_DEBUG_UART_INSTANCE, BOARD_DEBUG_UART_BAUDRATE, BOARD_DEBUG_UART_TYPE, uartClkSrcFreq);
}

#if defined(SDK_I2C_BASED_COMPONENT_USED) && SDK_I2C_BASED_COMPONENT_USED
void BOARD_I2C_Init(I2C_Type *base, uint32_t clkSrc_Hz)
{
    i2c_master_config_t i2cConfig = {0};

    I2C_MasterGetDefaultConfig(&i2cConfig);
    I2C_MasterInit(base, &i2cConfig, clkSrc_Hz);
}

status_t BOARD_I2C_Send(I2C_Type *base,
                        uint8_t deviceAddress,
                        uint32_t subAddress,
                        uint8_t subaddressSize,
                        uint8_t *txBuff,
                        uint8_t txBuffSize)
{
    i2c_master_transfer_t masterXfer;

    /* Prepare transfer structure. */
    masterXfer.slaveAddress   = deviceAddress;
    masterXfer.direction      = kI2C_Write;
    masterXfer.subaddress     = subAddress;
    masterXfer.subaddressSize = subaddressSize;
    masterXfer.data           = txBuff;
    masterXfer.dataSize       = txBuffSize;
    masterXfer.flags          = kI2C_TransferDefaultFlag;

    return I2C_MasterTransferBlocking(base, &masterXfer);
}

status_t BOARD_I2C_Receive(I2C_Type *base,
                           uint8_t deviceAddress,
                           uint32_t subAddress,
                           uint8_t subaddressSize,
                           uint8_t *rxBuff,
                           uint8_t rxBuffSize)
{
    i2c_master_transfer_t masterXfer;

    /* Prepare transfer structure. */
    masterXfer.slaveAddress   = deviceAddress;
    masterXfer.subaddress     = subAddress;
    masterXfer.subaddressSize = subaddressSize;
    masterXfer.data           = rxBuff;
    masterXfer.dataSize       = rxBuffSize;
    masterXfer.direction      = kI2C_Read;
    masterXfer.flags          = kI2C_TransferDefaultFlag;

    return I2C_MasterTransferBlocking(base, &masterXfer);
}

void BOARD_Accel_I2C_Init(void)
{
    BOARD_I2C_Init(BOARD_ACCEL_I2C_BASEADDR, BOARD_ACCEL_I2C_CLOCK_FREQ);
}

status_t BOARD_Accel_I2C_Send(uint8_t deviceAddress, uint32_t subAddress, uint8_t subaddressSize, uint32_t txBuff)
{
    uint8_t data = (uint8_t)txBuff;

    return BOARD_I2C_Send(BOARD_ACCEL_I2C_BASEADDR, deviceAddress, subAddress, subaddressSize, &data, 1);
}

status_t BOARD_Accel_I2C_Receive(
    uint8_t deviceAddress, uint32_t subAddress, uint8_t subaddressSize, uint8_t *rxBuff, uint8_t rxBuffSize)
{
    return BOARD_I2C_Receive(BOARD_ACCEL_I2C_BASEADDR, deviceAddress, subAddress, subaddressSize, rxBuff, rxBuffSize);
}

void BOARD_Codec_I2C_Init(void)
{
    BOARD_I2C_Init(BOARD_CODEC_I2C_BASEADDR, BOARD_CODEC_I2C_CLOCK_FREQ);
}

status_t BOARD_Codec_I2C_Send(
    uint8_t deviceAddress, uint32_t subAddress, uint8_t subAddressSize, const uint8_t *txBuff, uint8_t txBuffSize)
{
    return BOARD_I2C_Send(BOARD_CODEC_I2C_BASEADDR, deviceAddress, subAddress, subAddressSize, (uint8_t *)txBuff,
                          txBuffSize);
}

status_t BOARD_Codec_I2C_Receive(
    uint8_t deviceAddress, uint32_t subAddress, uint8_t subAddressSize, uint8_t *rxBuff, uint8_t rxBuffSize)
{
    return BOARD_I2C_Receive(BOARD_CODEC_I2C_BASEADDR, deviceAddress, subAddress, subAddressSize, rxBuff, rxBuffSize);
}
#endif /* SDK_I2C_BASED_COMPONENT_USED */
/**
 * @cond
 ***********************************************************************************************************************
 *
 * Copyright (c) 2018, Infineon Technologies AG
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,are permitted provided that the
 * following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this list of conditions and the  following
 *   disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the
 *   following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *   Neither the name of the copyright holders nor the names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT  OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 **********************************************************************************************************************/
#ifndef ADC1_DEFINES_H
#define ADC1_DEFINES_H

/* XML Version 2.3.4 */
#define ADC1_XML_VERSION (20304)

#define ADC1_CH0_LOTH_VOLT (6.40)

#define ADC1_CH0_UPTH_VOLT (24.00)

#define ADC1_CH10_LOTH_VOLT (4.50)

#define ADC1_CH10_UPTH_VOLT (2.50)

#define ADC1_CH11_LOTH_VOLT (4.50)

#define ADC1_CH11_UPTH_VOLT (2.50)

#define ADC1_CH1_LOTH_VOLT (6.40)

#define ADC1_CH1_UPTH_VOLT (24.00)

#define ADC1_CH2_LOTH_VOLT (5.40)

#define ADC1_CH2_UPTH_VOLT (8.10)

#define ADC1_CH3_LOTH_VOLT (5.40)

#define ADC1_CH3_UPTH_VOLT (8.10)

#define ADC1_CH4_LOTH_VOLT (5.40)

#define ADC1_CH4_UPTH_VOLT (8.10)

#define ADC1_CH5_LOTH_VOLT (5.40)

#define ADC1_CH5_UPTH_VOLT (8.10)

#define ADC1_CH6_LOTH_VOLT (5.40)

#define ADC1_CH6_UPTH_VOLT (8.10)

#define ADC1_CH7_LOTH_VOLT (4.50)

#define ADC1_CH7_UPTH_VOLT (2.50)

#define ADC1_CH8_LOTH_VOLT (4.50)

#define ADC1_CH8_UPTH_VOLT (2.50)

#define ADC1_CH9_LOTH_VOLT (4.50)

#define ADC1_CH9_UPTH_VOLT (2.50)

#define ADC1_CHx_EIM (0x0u) /*decimal 0*/

#define ADC1_CHx_ESM (0x40010100u) /*decimal 1073807616*/

#define ADC1_CLK (0x19u) /*decimal 25*/

#define ADC1_CNT0_3_LOWER (0x12131312u) /*decimal 303239954*/

#define ADC1_CNT0_3_UPPER (0x12131B1Au) /*decimal 303242010*/

#define ADC1_CNT4_7_LOWER (0x0u) /*decimal 0*/

#define ADC1_CNT4_7_UPPER (0x0u) /*decimal 0*/

#define ADC1_CNT8_11_LOWER (0x0u) /*decimal 0*/

#define ADC1_CNT8_11_UPPER (0x0u) /*decimal 0*/

#define ADC1_CTRL2 (0x0u) /*decimal 0*/

#define ADC1_CTRL3 (0x70701u) /*decimal 460545*/

#define ADC1_CTRL5 (0x0u) /*decimal 0*/

#define ADC1_DCH1_LOTH_VOLT (5.40)

#define ADC1_DCH1_UPTH_VOLT (8.10)

#define ADC1_DCH2_LOTH_VOLT (5.40)

#define ADC1_DCH2_UPTH_VOLT (8.10)

#define ADC1_DCH3_LOTH_VOLT (5.40)

#define ADC1_DCH3_UPTH_VOLT (8.10)

#define ADC1_DCH4_LOTH_VOLT (5.40)

#define ADC1_DCH4_UPTH_VOLT (8.10)

#define ADC1_DCHCNT1_4_LOWER (0x0u) /*decimal 0*/

#define ADC1_DCHCNT1_4_UPPER (0x0u) /*decimal 0*/

#define ADC1_DCHTH1_4_LOWER (0x2C2C2C2Cu) /*decimal 741092396*/

#define ADC1_DCHTH1_4_UPPER (0x42424242u) /*decimal 1111638594*/

#define ADC1_DIFFCH_OUT1 (0x0u) /*decimal 0*/

#define ADC1_DIFFCH_OUT2 (0x0u) /*decimal 0*/

#define ADC1_DIFFCH_OUT3 (0x0u) /*decimal 0*/

#define ADC1_DIFFCH_OUT4 (0x0u) /*decimal 0*/

#define ADC1_DUIN_SEL (0x0u) /*decimal 0*/

#define ADC1_FILTCOEFF0_11 (0x0u) /*decimal 0*/

#define ADC1_FILT_LO_CTRL (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT0 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT1 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT10 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT11 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT2 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT3 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT4 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT5 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT6 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT7 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT8 (0x0u) /*decimal 0*/

#define ADC1_FILT_OUT9 (0x0u) /*decimal 0*/

#define ADC1_FILT_UP_CTRL (0x0u) /*decimal 0*/

#define ADC1_IRQEN_1 (0x20000u) /*decimal 131072*/

#define ADC1_IRQEN_2 (0x0u) /*decimal 0*/

#define ADC1_MMODE0_11 (0x0u) /*decimal 0*/

#define ADC1_MODE_SELECT (0x1u) /*decimal 1*/

#define ADC1_MSG1 (0xDu) /*decimal 13*/

#define ADC1_MSG2 (0x6u) /*decimal 6*/

#define ADC1_SQ0_1 (0x3u) /*decimal 3*/

#define ADC1_SQ10_11 (0x0u) /*decimal 0*/

#define ADC1_SQ2_3 (0x0u) /*decimal 0*/

#define ADC1_SQ4_5 (0x0u) /*decimal 0*/

#define ADC1_SQ6_7 (0x0u) /*decimal 0*/

#define ADC1_SQ8_9 (0x0u) /*decimal 0*/

#define ADC1_TH0_3_LOWER (0x2C2C3F3Fu) /*decimal 741097279*/

#define ADC1_TH0_3_UPPER (0x4242EDEDu) /*decimal 1111682541*/

#define ADC1_TH4_7_LOWER (0xCF2C2C2Cu) /*decimal 3475778604*/

#define ADC1_TH4_7_UPPER (0x73424242u) /*decimal 1933722178*/

#define ADC1_TH8_11_LOWER (0xCFCFCFCFu) /*decimal 3486502863*/

#define ADC1_TH8_11_UPPER (0x73737373u) /*decimal 1936946035*/

#define SCU_MODPISEL4 (0x7070707u) /*decimal 117901063*/

#endif /* ADC1_DEFINES_H */
